@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -26,7 +26,7 @@
 
 namespace testing
 {
-#if   GTEST_MINORVER == 0x07
+#if   GTEST_MAJORVER > 1 || GTEST_MINORVER >= 0x07
 	typedef ::std::string				GTestAssertionResultString;
 	typedef ::std::string				GTestString;
 #elif GTEST_MINORVER == 0x06
