@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -57,7 +57,7 @@ public:
 	static bool ValidateTestPropertyName(const ::std::string& name)
 	{
 		const char* ban[] = { "name", "tests", "failures", "disabled", "skip", "errors", "time", "timestamp", "random_seed" };
-#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
 		return TestProperty::ValidateName(name, ban);
 #else
 		return TestProperty::ValidateName(name, ban, ban+IUTEST_PP_COUNTOF(ban));
@@ -185,8 +185,7 @@ template<typename T>
 ::std::string MakeIndexTypedTestName(const char* basename, int index)
 {
 #if IUTEST_HAS_RTTI
-	::std::string name = basename;
-	iuStringStream::type strm; strm << index;
+	::std::string name = MakeIndexTestName(basename, index);
 	name += "/";
 	name += GetTypeName<T>();
 	return name;
