@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -19,7 +19,6 @@
 
 //======================================================================
 // include
-#include "iutest_string.hpp"
 #include "iutest_port.hpp"
 
 #if IUTEST_HAS_FILE_STAT
@@ -38,7 +37,7 @@ namespace posix
 
 #if IUTEST_HAS_FILE_STAT
 
-#if defined(IUTEST_OS_WINDOWS)
+#if defined(IUTEST_OS_WINDOWS) && !defined(IUTEST_OS_WINDOWS_WINE)
 
 	typedef struct _stat StatStruct;
 
@@ -182,21 +181,12 @@ public:
 	*/
 	static iuFilePath ConcatPaths(const iuFilePath& directory, const iuFilePath& relative_path);
 
-public:
-	/**
-	 * @brief	パス区切り文字の取得
-	*/
-	static char GetPathSeparator(void) IUTEST_CXX_NOEXCEPT_SPEC;
-
 private:
 	/**
 	 * @biref	正規化
 	*/
 	void Normalize(void);
 
-private:
-	static bool IsPathSeparator(char c) IUTEST_CXX_NOEXCEPT_SPEC;
-	static bool IsAltPathSeparator(char c) IUTEST_CXX_NOEXCEPT_SPEC;
 private:
 	::std::string m_path;
 };
