@@ -171,6 +171,25 @@
 
 #endif
 
+#define IUTEST_CLASS_INITIALIZE(methodName)		static void SetUpTestCase() { methodName(); } static void methodName()
+#define IUTEST_CLASS_CLEANUP(methodName)		static void TearDownTestCase() { methodName(); } static void methodName()
+
+#define IUTEST_METHOD_INITIALIZE(methodName)	virtual void SetUp() IUTEST_CXX_OVERRIDE { methodName(); } void methodName()
+#define IUTEST_METHOD_CLEANUP(methodName)		virtual void TearDown() IUTEST_CXX_OVERRIDE { methodName(); } void methodName()
+
+/**
+ * @private
+ * @{
+*/
+#define IUTEST_CLASS_INITIALIZE(methodName)		static void SetUpTestCase() { methodName(); } static void methodName()
+#define IUTEST_CLASS_CLEANUP(methodName)		static void TearDownTestCase() { methodName(); } static void methodName()
+
+#define IUTEST_METHOD_INITIALIZE(methodName)	virtual void SetUp() IUTEST_CXX_OVERRIDE { methodName(); } void methodName()
+#define IUTEST_METHOD_CLEANUP(methodName)		virtual void TearDown() IUTEST_CXX_OVERRIDE { methodName(); } void methodName()
+/**
+ * @}
+*/
+
 /**
  * @internal
  * @brief	Assertion message
