@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -59,6 +59,32 @@
 namespace iutest_type_traits
 {
 
+/**
+ * @brief	identity
+*/
+template<typename T>struct identity { typedef T type; };
+
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+
+/**
+* @brief	add const to pointer
+*/
+template<typename T>
+class add_const_to_pointer
+{
+	template<typename U, typename DMY>struct impl { typedef const U type; };
+	template<typename U, typename DMY>struct impl<U*, DMY>
+	{
+		typedef const U* type;
+	};
+
+public:
+	typedef typename impl<T, void>::type type;
+};
+
+#endif
+
+
 #if IUTEST_HAS_HDR_TYPETARITS
 
 using ::std::true_type;
