@@ -29,6 +29,14 @@ namespace iutest
 //! Message クラス
 typedef detail::iuStreamMessage	Message;
 
+//======================================================================
+// function
+template<typename T>
+inline ::std::string StreamableToString(const T& value)
+{
+	return (Message() << value).GetString();
+}
+
 //======================================================================
 // declare
 namespace detail
