@@ -29,6 +29,13 @@ namespace iutest
 template<typename T>class WithParamInterface;
 template<typename T>class TestWithParam;
 
+namespace detail
+{
+
+::std::string MakeIndexTestName(const char* basename, int index);
+
+}
+
 //======================================================================
 // class
 /**
@@ -254,6 +261,15 @@ public:
 	}
 #endif
 
+	/**
+	 * @brief	テスト名の生成
+	*/
+	template<typename U>
+	static const ::std::string MakeTestName(const char* basename, int index, const U&)
+	{
+		return detail::MakeIndexTestName(basename, index);
+	}
+
 	/** @private */
 	static void SetParam(const ParamType* params) IUTEST_CXX_NOEXCEPT_SPEC { s_params = params; }
 
