@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -48,8 +48,8 @@
 #  define IUTEST_VPRINTF(f, a)	vprintf(f, a)	//!< vprintf 呼び出しマクロ
 #endif
 
-#if !defined(IUTEST_REPORT_SKIPPED)
-#  define IUTEST_REPORT_SKIPPED		1			//!< xml 出力に skipped タグを含めるかどうか
+#if !defined(IUTEST_HAS_REPORT_SKIPPED)
+#  define IUTEST_HAS_REPORT_SKIPPED		1		//!< xml 出力に skipped タグを含めるかどうか
 #endif
 
 /**
@@ -114,7 +114,11 @@
 /**
  * @brief	IUTEST_*_THAT が使用可能かどうか
 */
-#  define IUTEST_HAS_MATCHERS		1
+#  if !defined(IUTEST_NO_SFINAE) && !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING) && !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#    define IUTEST_HAS_MATCHERS		1
+#  else
+#    define IUTEST_HAS_MATCHERS		0
+#  endif
 #endif
 
 #if !defined(IUTEST_HAS_ARITHMETIC_EXPRESSION_DECOMPOSE)
@@ -228,13 +232,40 @@
 
 #if !defined(IUTEST_HAS_MATCHER_ELEMENTSARE)
 //! ::iutest::ElementsAre matcher が使用可能かどうか
-#  if IUTEST_HAS_TUPLE && IUTEST_HAS_MATCHERS
+#  if IUTEST_HAS_TUPLE && IUTEST_HAS_MATCHERS && !defined(IUTEST_NO_SFINAE)
 #    define IUTEST_HAS_MATCHER_ELEMENTSARE		1
 #  else
 #    define IUTEST_HAS_MATCHER_ELEMENTSARE		0
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_MATCHER_ELEMENTSAREARRAYFORWARD)
+//! ::iutest::ElementsAreArrayHead matcher が使用可能かどうか
+#  if IUTEST_HAS_TUPLE && IUTEST_HAS_MATCHERS && !defined(IUTEST_NO_SFINAE)
+#    define IUTEST_HAS_MATCHER_ELEMENTSAREARRAYFORWARD	1
+#  else
+#    define IUTEST_HAS_MATCHER_ELEMENTSAREARRAYFORWARD	0
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_REGEX)
+//! regex が使用可能かどうか
+#  if IUTEST_HAS_CXX_HDR_REGEX
+#    define IUTEST_HAS_REGEX	1
+#  else
+#    define IUTEST_HAS_REGEX	0
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_MATCHER_REGEX)
+//! ::iutest::MatchesRegex, ::iutest::ContainsRegex matcher が使用可能かどうか
+#  if IUTEST_HAS_CXX_HDR_REGEX && IUTEST_HAS_MATCHERS && IUTEST_HAS_REGEX
+#    define IUTEST_HAS_MATCHER_REGEX	1
+#  else
+#    define IUTEST_HAS_MATCHER_REGEX	0
+#  endif
+#endif
+
 #if !defined(IUTEST_HAS_MATCHER_ALLOF_AND_ANYOF)
 //! ::iutest::AllOf, ::iutest::AnyOf matcher が使用可能かどうか
 #  if IUTEST_HAS_TUPLE && IUTEST_HAS_MATCHERS
@@ -315,6 +346,15 @@
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_PEEP_CLASS)
+//! private メンバー関数へのアクセスが可能かどうか
+#  if IUTEST_HAS_PEEP && !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#    define IUTEST_HAS_PEEP_CLASS	1
+#  else
+#    define IUTEST_HAS_PEEP_CLASS	0
+#  endif
+#endif
+
 #if !defined(IUTEST_HAS_STATIC_ASSERT_TYPEEQ)
 //! StaticAssertTypeEq が使用可能かどうか
 #if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
@@ -396,6 +436,10 @@
 #  endif
 #endif
 
+#if !defined(IUTEST_TYPED_TEST_APPEND_TYPENAME)
+//! 型付けテスト名に型名を付けるかどうか
+#  define IUTEST_TYPED_TEST_APPEND_TYPENAME	0
+#endif
 
 /**
  * @}
@@ -469,6 +513,11 @@
  * @{
 */
 
+//! テストのチェック機能の有無
+#if !defined(IUTEST_CHECK_STRICT)
+#  define IUTEST_CHECK_STRICT		1
+#endif
+
 #if !defined(IUTEST_HAS_MINIDUMP)
 //! MiniDump 出力が有効かどうか
 #  if defined(_MSC_VER) && _MSC_VER >= 1310
