@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -20,7 +20,6 @@
 #include "iutest_any.hpp"
 
 #if IUTEST_HAS_PARAM_TEST
-#include "internal/iutest_pool.hpp"
 
 //======================================================================
 // define
@@ -93,7 +92,7 @@
 	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder<T>(testcase_, package_)
 #else
 #  define IIUT_GETTESTCASEPATTERNHOLDER(T, testcase_, package_)	\
-	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder(testcase_, package_, &::iutest::detail::type<T>())
+	::iutest::UnitTest::GetInstance()->parameterized_test_registry().GetTestCasePatternHolder(testcase_, package_, ::iutest::detail::explicit_type<T>())
 #endif
 
 #if IUTEST_HAS_AUTOFIXTURE_PARAM_TEST
@@ -194,33 +193,35 @@ namespace detail
  * @brief	パラメータ単体テスト TestInfo 情報インスタンス
 */
 template<typename T>
-class ParamTestInstance : public IParamTestInfoData<typename T::ParamType>
+class ParamTestInstance : public IParamTestInfoData
 {
-	typedef T								Tester;
-	typedef typename Tester::ParamType		ParamType;
-	typedef detail::iuParamTestFactory<T>	Factory;
-	typedef IParamTestInfoData<ParamType>	_Mybase;
+	typedef T Tester;
+	typedef typename Tester::ParamType ParamType;
+	typedef detail::iuParamTestFactory<T> Factory;
 
 	// 各テストのインスタンス
-	class EachTest : public IParamEachTestBase
+	class EachTest IUTEST_CXX_FINAL : public IParamTestInfoData::ParamEachTestBase<ParamType>
 	{
 	public:
-		EachTest(TestCase* testcase, const char* name, ParamType param)
+		EachTest(TestCase* testcase, const char* name)
 			: m_mediator(testcase)
-			, m_factory(param)
 			, m_info(&m_mediator, name, &m_factory)
 		{
 			UnitTest::instance().AddTestInfo(testcase, &m_info);
+		}
+	private:
+		virtual void SetParam(const ParamType& param) IUTEST_CXX_OVERRIDE
+		{
+			m_factory.SetParam(param);
 			m_info.set_value_param(PrintToString(param).c_str());
 		}
-		~EachTest(void) {}
 	private:
 		TestCaseMediator	m_mediator;
 		Factory				m_factory;
 		TestInfo			m_info;
 	};
 public:
-	ParamTestInstance(const char* testcase_name) : _Mybase(testcase_name) {}
+	ParamTestInstance(const char* testcase_name) : IParamTestInfoData(testcase_name) {}
 
 private:
 	// テストケースの作成
@@ -229,16 +230,17 @@ private:
 #if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
 		return UnitTest::instance().AddTestCase<TestCase>(testcase_name, id, setup, teardown);
 #else
-		return UnitTest::instance().AddTestCase(testcase_name, id, setup, teardown, &detail::type<TestCase>());
+		return UnitTest::instance().AddTestCase(testcase_name, id, setup, teardown, detail::explicit_type<TestCase>());
 #endif
 	}
 
 	// テストの作成登録
-	virtual void RegisterTest(TestCase* testcase, ParamType param, int index) const IUTEST_CXX_OVERRIDE
+	virtual IParamTestInfoData::EachTestBase* RegisterTest(TestCase* testcase, const char* name) const IUTEST_CXX_OVERRIDE
 	{
-		EachTest* test = new EachTest(testcase, detail::MakeIndexTestName(this->m_name.c_str(), index).c_str(), param);
+		EachTest* test = new EachTest(testcase, name);
 		// new オブジェクトを管理してもらう
-		detail::iuPool<IParamEachTestBase>::GetInstance().push(test);
+		detail::iuPool::GetInstance().push(test);
+		return test;
 	}
 };
 
@@ -354,24 +356,28 @@ inline detail::iuRandomParamsHolder IUTEST_ATTRIBUTE_UNUSED_ RandomValues(size_t
  * @brief	値配列パラメータ
 */
 template<typename Container>
-inline detail::iuParamGenerator< typename Container::value_type > IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(Container containor)
+inline detail::iuParamGenerator< typename Container::value_type > IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(Container container)
 {
-	return new detail::iuValuesInParamsGenerator< typename Container::value_type >(containor);
+	return new detail::iuValuesInParamsGenerator< typename Container::value_type >(container);
 }
 
-#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
 /** @overload */
 template<typename T, size_t SIZE>
 inline detail::iuParamGenerator<T> IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(const T (&v)[SIZE])
 {
 	return new detail::iuValuesInParamsGenerator<T>(v, v+SIZE);
 }
+
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 /** @overload */
 template<typename Ite>
 inline detail::iuParamGenerator< typename detail::IteratorTraits<Ite>::type > IUTEST_ATTRIBUTE_UNUSED_ ValuesIn(Ite begin, Ite end)
 {
 	return new detail::iuValuesInParamsGenerator< typename detail::IteratorTraits<Ite>::type >(begin, end);
 }
+#endif
+
 #if IUTEST_HAS_INITIALIZER_LIST
 /** @overload */
 template<typename T>
