@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -206,7 +206,7 @@
 
 #define IIUT_REGISTER_TYPED_TEST_CASE_P_(testcase_, ...)								\
 	namespace IUTEST_TYPED_TEST_P_NAMESPACE_(testcase_) {								\
-		typedef ::iutest::detail::Templates< __VA_ARGS__ >::type	iutest_AllTests_;	\
+		typedef ::iutest::detail::Templates< __VA_ARGS__ >::type iutest_AllTests_;		\
 	}																					\
 	static const bool s_iutest_##testcase_##_register_dummy_ IUTEST_ATTRIBUTE_UNUSED_ =	\
 	IUTEST_TYPED_TEST_CASE_PSTATE_NAME_(testcase_).VerifyTestNames(__FILE__, __LINE__, #__VA_ARGS__)
@@ -256,16 +256,34 @@ class TypeParamTestInstance
 	public:
 		// コンストラクタ
 		EachTest(const char* testcase, const char* name, int index)
-			: m_mediator(UnitTest::instance().AddTestCase<_MyTestCase>(
-				detail::MakeIndexTestName(testcase, index).c_str()
-				//detail::MakeIndexTypedTestName<TypeParam>(testcase, index).c_str()
-				, internal::GetTypeId<detail::None>()	// TypeId を統一するためダミー引数を渡す
-				, TestBody::SetUpTestCase
-				, TestBody::TearDownTestCase))
+			: m_mediator(AddTestCase(testcase, index))
 			, m_info(&m_mediator, name, &m_factory)
 			, m_next(testcase, name, index+1)
 		{
 		}
+
+	private:
+		static TestCase* AddTestCase(const char* testcase, int index)
+		{
+#if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
+			return UnitTest::instance().AddTestCase<_MyTestCase>(
+#else
+			return UnitTest::instance().AddTestCase(
+#endif
+#if IUTEST_TYPED_TEST_APPEND_TYPENAME
+				detail::MakeIndexTypedTestName<TypeParam>(testcase, index).c_str()
+#else
+				detail::MakeIndexTestName(testcase, index).c_str()
+#endif
+				, internal::GetTypeId<detail::None>()	// TypeId を統一するためダミー引数を渡す
+				, TestBody::SetUpTestCase
+				, TestBody::TearDownTestCase
+#if defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
+				, detail::explicit_type<_MyTestCase>()
+#endif
+				);
+		}
+
 	public:
 		// テストの登録
 		void AddTest(void)
@@ -316,6 +334,10 @@ private:
 */
 class TypedTestCasePState
 {
+#if IUTEST_TYPED_TEST_P_STRICT
+	typedef ::std::set<const char*> nameset_t;
+#endif
+
 public:
 	TypedTestCasePState(void) : m_names(NULL) {}
 public:
@@ -326,9 +348,9 @@ public:
 	{
 		if( m_names != NULL )
 		{
-			fprintf(stderr, "%s Test %s must be defined before IUTEST_REGISTER_TYPED_TEST_CASE_P(%s, ...).\n"
-				, detail::FormatCompilerIndependentFileLocation(file, line).c_str(), test_name, testcase_name);
-			fflush(stderr);
+			IUTEST_LOG_(WARNING) << detail::FormatCompilerIndependentFileLocation(file, line)
+				<< ": Test " << test_name << " must be defined before IUTEST_REGISTER_TYPED_TEST_CASE_P("
+				<< testcase_name << ", ...).\n";
 		}
 #if IUTEST_TYPED_TEST_P_STRICT
 		m_list.insert(test_name);
@@ -338,38 +360,29 @@ public:
 	bool VerifyTestNames(const char* file, int line, const char* test_names)
 	{
 		m_names = test_names;
-		IUTEST_UNUSED_VAR(file);
-		IUTEST_UNUSED_VAR(line);
-		return Verify(test_names);
-	}
-
-private:
-	bool Verify(const char* names)
-	{
 		IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 #if IUTEST_TYPED_TEST_P_STRICT
-		if( names == NULL )
+		bool ret = true;
+		for( nameset_t::iterator it=m_list.begin(), end=m_list.end(); it != end; ++it )
 		{
-			return true;
+			const char* test_name = *it;
+			const char* p = strstr(test_names, test_name);
+			if( p != NULL )
+			{
+				const size_t len = strlen(test_name);
+				if( p[len] == '\0' || p[len] == ',' || detail::IsSpace(p[len]) )
+				{
+					continue;
+				}
+			}
+			IUTEST_LOG_(WARNING) << detail::FormatCompilerIndependentFileLocation(file, line)
+				<< ": Test " << test_name << " has not been registered.\n";
+			ret = false;
 		}
-		const char* comma = FindComma(names);
-		::std::string name;
-		if( comma == NULL )
-		{
-			name = names;
-		}
-		else
-		{
-			name.append(names, comma - names);
-			++comma;
-		}
-		if( m_list.find(name.c_str()) == m_list.end() )
-		{
-			return false;
-		}
-		return Verify(SkipSpace(comma));
+		return ret;
 #else
-		IUTEST_UNUSED_VAR(names);
+		IUTEST_UNUSED_VAR(file);
+		IUTEST_UNUSED_VAR(line);
 		return true;
 #endif
 		IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
@@ -379,22 +392,12 @@ private:
 	const char* m_names;
 
 #if IUTEST_TYPED_TEST_P_STRICT
-	::std::set<const char*> m_list;
+	nameset_t m_list;
 #endif
 
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(TypedTestCasePState);
 };
 
-/**
- * @private
- * @brief	型パラメータテストのインスタンスベースクラス
-*/
-class ITypedParameEachTestBase
-{
-public:
-	virtual ~ITypedParameEachTestBase(void) {}
-};
-
 /**
  * @private
  * @brief	型パラメータテストのインスタンス化クラス
@@ -403,7 +406,7 @@ template<IUTEST_TEMPLATE_TPARAM1 Fixture, typename Tests, typename Types>
 class TypeParameterizedTestCase
 {
 	template<typename TypeParam, typename TestsList>
-	class EachTest : public ITypedParameEachTestBase
+	class EachTest : public iuIObject
 	{
 		typedef typename TestsList::Head 		TypeSel;
 		typedef typename TypeSel::template bind<TypeParam>::type	TestBody;
@@ -433,9 +436,10 @@ IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_BEGIN()
 				test_name.append(str, comma - str);
 				++comma;
 			}
+			StripTrailingSpace(test_name);
 			_Myt* test = new EachTest(testcase, test_name.c_str());
 			// new オブジェクトを管理してもらう
-			detail::iuPool<ITypedParameEachTestBase>::GetInstance().push(test);
+			detail::iuPool::GetInstance().push(test);
 
 			EachTest<TypeParam, typename TestsList::Tail>::Register(testcase, detail::SkipSpace(comma));
 IUTEST_PRAGMA_CONSTEXPR_CALLED_AT_RUNTIME_WARN_DISABLE_END()
@@ -463,11 +467,23 @@ public:
 		typedef typename Tests::Head	Head;
 		typedef Fixture<Head>			FixtureClass;
 		typedef TypedTestCase<TypeParam>	_MyTestCase;
-		TestCase* testcase = UnitTest::instance().AddTestCase<_MyTestCase>(
+		TestCase* testcase = 
+#if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
+			UnitTest::instance().AddTestCase<_MyTestCase>(
+#else
+			UnitTest::instance().AddTestCase(
+#endif
+#if IUTEST_TYPED_TEST_APPEND_TYPENAME
+			(package_name + detail::MakePrefixedIndexTypedTestName<TypeParam>(prefix, testcase_name, index)).c_str()
+#else
 			(package_name + detail::MakePrefixedIndexTestName(prefix, testcase_name, index)).c_str()
-			//detail::MakePrefixedIndexTypedTestName<TypeParam>(prefix, testcase_name, index).c_str()
+#endif
 			, internal::GetTypeId<FixtureClass>()
-			, FixtureClass::SetUpTestCase, FixtureClass::TearDownTestCase);
+			, FixtureClass::SetUpTestCase, FixtureClass::TearDownTestCase
+#if defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
+			, detail::explicit_type<_MyTestCase>()
+#endif
+			);
 
 		EachTest<TypeParam, Tests>::Register(testcase, names);
 
