@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -17,21 +17,21 @@
 
 //======================================================================
 // define
-#define IUTEST_VER			0x01110000u //!< iutest version 1.11.0.0
+#define IUTEST_VER			0x01130000u //!< iutest version 1.13.0.0
 #define IUTEST_MAJORVER		0x01u		//!< Major Version
-#define IUTEST_MINORVER		0x11u		//!< Minor Version
+#define IUTEST_MINORVER		0x13u		//!< Minor Version
 #define IUTEST_BUILD		0x00u		//!< Build
 #define IUTEST_REVISION		0x00u		//!< Revision
 
 /**
  * @mainpage
  * @sa	@b	ProjectHome \n
- *			sourceforge : http://sourceforge.jp/projects/iutest/ \n
+ *			OSDN        : http://osdn.jp/projects/iutest/ \n
  *			github		: https://github.com/srz-zumix/iutest \n
  *			google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
  *
  * @par		copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License.
  *
  * @par		LICENSE
@@ -70,6 +70,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    <tr><td>--iutest_list_tests               </td><td></td><td>List up tests.</td></tr>
    <tr><td>--iutest_list_tests_with_where    </td><td></td><td>List up tests with where.</td></tr>
    <tr><td>--iutest_color                    </td><td>&lt;yes|no|auto|ansi&gt;</td><td>Console color enable.</td></tr>
+   <tr><td>--iutest_flagfile                 </td><td>&lt;file&gt;</td><td>Set the flag from the file.</td></tr>
    <tr><td>--iutest_filter                   </td><td>&lt;filter&gt;</td><td>Select the test run.</td></tr>
    <tr><td>--iutest_shuffle                  </td><td></td><td>Do shuffle test.</td></tr>
    <tr><td>--iutest_random_seed              </td><td>&lt;seed&gt;</td><td>Set random seed.</td></tr>
@@ -95,6 +96,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  <table>
    <tr><td>IUTEST_OUTPUT=xml|junit[:path]  </td><td>Path of xml report.</td></tr>
    <tr><td>IUTEST_COLOR=yes|no|auto        </td><td>Console color enable.</td></tr>
+   <tr><td>IUTEST_FLAGFILE=file            </td><td>Set the flag from the file.</td></tr>
    <tr><td>IUTEST_FILTER=filter            </td><td>Select the test run.</td></tr>
    <tr><td>IUTEST_SHUFFLE                  </td><td>Do shuffle test.</td></tr>
    <tr><td>IUTEST_RANDOM_SEED=seed         </td><td>Set random seed.</td></tr>
@@ -113,6 +115,37 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @page	CHANGELOG	変更履歴
  * @par		Changes
  <ul>
+  <li>v1.13.0.0
+    <ul>
+      <li>--iutest_flagfile コマンドラインオプションに対応</li>
+      <li>MFC コンテナ対応</li>
+      <li>値のパラメータ化テストのテスト名指定に対応</li>
+      <li>型付けテストのテスト名に型名をつけるオプションマクロ (IUTEST_TYPED_TEST_APPEND_TYPENAME) を追加</li>
+      <li>非ヨーダ記法を提供するヘッダーを追加</li>
+      <li>Visual Studio 2015 対応</li>
+      <li>tr1/iutest_vc_unittest.hpp を修正</li>
+    </ul>
+  </li>
+  <li>v1.12.0.0
+    <ul>
+      <li>IUTEST_PACKAGE v2 (多重定義制限の撤廃)</li>
+      <li>Matcher に MatchesRegex,ContainsRegex を追加</li>
+      <li>Matcher に ElementsAreArrayForward を追加</li>
+      <li>ElementsAreArray で要素数の一致チェックを行うように変更（以前までの ElementsAreArray は ElementsAreArrayForward に変更）</li>
+      <li>IUTEST_*_MATCHES_REGEXEQ,NE、IUTEST_*_CONTAINS_REGEXEQ,NE 追加</li>
+      <li>--iutest_filter=@filter.txt のようにファイルからフィルター指定できるように対応</li>
+      <li>IUTEST_MAKE_PEEP で関数ポインターの typedef をしなくてもいいように修正</li>
+      <li>quick_exit 対応</li>
+      <li>IUTEST_REPORT_SKIPPED を IUTEST_HAS_REPORT_SKIPPED に変更</li>
+      <li>Visual Studio 2015 Preview 対応</li>
+      <li>twilio 対応</li>
+    </ul>
+  </li>
+  <li>v1.11.1.0
+    <ul>
+      <li>IUTEST_REGISTER_TYPED_TEST_CASE_P でテスト名の後ろの空白が名前に含まれてしまう不具合を修正</li>
+    </ul>
+  </li>
   <li>v1.11.0.0
     <ul>
       <li>fused-src 対応</li>
@@ -122,13 +155,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
       <li>Matcher に FloatEq,DoubleEq,NanSensitiveFloatEq,NanSensitiveDoubleEq を追加</li>
       <li>Matcher に Not,ResultOf,Pointee を追加</li>
       <li>コンテナMatcher に Each,ContainerEq,Pointwise,At,IsEmpty,SizeIs,ElementsAre,ElementsAreArray を追加</li>
-	  <li>コンテナMatcher の Contains から HasSubstr 機能を削除</li>
-	  <li>コンテナMatcher の条件に Matcher を使えるように修正</li>
+      <li>コンテナMatcher の Contains から HasSubstr 機能を削除</li>
+      <li>コンテナMatcher の条件に Matcher を使えるように修正</li>
       <li>メンバーMatcher に Key,Pair,Field を追加</li>
       <li>ワイルドカードMatcher A,_ を追加</li>
       <li>IUTEST_*_FLOAT_EQ,DOUBLE_EQ で NAN の比較が真を返す不具合を修正</li>
-	  <li>Visual Studio 2015 Preview 対応</li>
-	  </ul>
+      <li>Visual Studio 2015 Preview 対応</li>
+    </ul>
   </li>
   <li>v1.10.0.0
     <ul>
